pub async fn run_suite_with_options(
executor: &dyn EvalExecutor,
suite: &EvalSuite,
options: EvalRunOptions,
) -> Result<EvalReport>Expand description
Execute a suite with bounded concurrency and deterministic report order.
pub async fn run_suite_with_options(
executor: &dyn EvalExecutor,
suite: &EvalSuite,
options: EvalRunOptions,
) -> Result<EvalReport>Execute a suite with bounded concurrency and deterministic report order.