pub fn analyze_jsonl_file(path: impl AsRef<Path>) -> Result<HarnessTraceSummary>Expand description
Analyze a JSONL trace file and add path context to filesystem errors.
pub fn analyze_jsonl_file(path: impl AsRef<Path>) -> Result<HarnessTraceSummary>Analyze a JSONL trace file and add path context to filesystem errors.