pub struct LatencyStatistics {
pub count: u64,
pub total_ms: u64,
pub mean_ms: Option<f64>,
pub p50_ms: Option<u64>,
pub p95_ms: Option<u64>,
pub max_ms: Option<u64>,
}Expand description
Statistics over recorded latency samples, in milliseconds.
Fields
count: u64Number of latency samples.
total_ms: u64Sum of latency samples.
mean_ms: Option<f64>Arithmetic mean, or None when no samples were recorded.
p50_ms: Option<u64>Median from the bounded latency reservoir, or None when no samples were recorded.
p95_ms: Option<u64>95th percentile from the bounded latency reservoir, or None when no samples were recorded.
max_ms: Option<u64>Largest recorded sample, or None when no samples were recorded.