Privacy-preserving summaries for JSONL agent traces.
Structs
- Harness
Trace Summary - Redacted aggregate facts extracted from DeepSeek or VT Code JSONL traces.
- Latency
Statistics - Statistics over recorded latency samples, in milliseconds.
- Token
Usage - Aggregate token and prompt-cache usage found in a trace.
Functions
- analyze_
jsonl - Analyze JSONL text while retaining only aggregate, non-sensitive facts.
- analyze_
jsonl_ file - Analyze a JSONL trace file and add path context to filesystem errors.
- analyze_
jsonl_ reader - Analyze a buffered JSONL source without loading the complete trace into memory.